pub enum MessageStatus {
Accepted,
Delivered,
Responded,
Failed,
TimedOut,
Expired,
Cancelled,
}Expand description
Enumerates the finite message status cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Accepted
Use this variant when the contract needs to represent accepted; selecting it has no side effect by itself.
Delivered
Use this variant when the contract needs to represent delivered; selecting it has no side effect by itself.
Responded
Use this variant when the contract needs to represent responded; selecting it has no side effect by itself.
Failed
Use this variant when the contract needs to represent failed; selecting it has no side effect by itself.
TimedOut
Use this variant when the contract needs to represent timed out; selecting it has no side effect by itself.
Expired
Use this variant when the contract needs to represent expired; selecting it has no side effect by itself.
Cancelled
Use this variant when the contract needs to represent cancelled; selecting it has no side effect by itself.