IsolationMatchStatus

Enum IsolationMatchStatus 

pub enum IsolationMatchStatus {
    Matched,
    DowngradeApproved,
    DowngradeDenied,
    UnsupportedHost,
}
Enumerates the finite isolation match status cases. Serialized names are part of the SDK contract; update fixtures when variants change.

Variants



Matched

Use this variant when the contract needs to represent matched; selecting it has no side effect by itself.



DowngradeApproved

Use this variant when the contract needs to represent downgrade approved; selecting it has no side effect by itself.



DowngradeDenied

Use this variant when the contract needs to represent downgrade denied; selecting it has no side effect by itself.



UnsupportedHost

Use this variant when the contract needs to represent unsupported host; selecting it has no side effect by itself.