pub enum ApprovalTerminalStatus {
Approved,
ApprovedForSession,
Denied,
TimedOut,
Cancelled,
DispatcherUnavailable,
RecoveryRequired,
}Expand description
Enumerates the finite approval terminal status cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Approved
Use this variant when the contract needs to represent approved; selecting it has no side effect by itself.
ApprovedForSession
Use this variant when the contract needs to represent approved for session; selecting it has no side effect by itself.
Denied
Use this variant when the contract needs to represent denied; selecting it has no side effect by itself.
TimedOut
Use this variant when the contract needs to represent timed out; selecting it has no side effect by itself.
Cancelled
Use this variant when the contract needs to represent cancelled; selecting it has no side effect by itself.
Use this variant when the contract needs to represent dispatcher unavailable; selecting it has no side effect by itself.
RecoveryRequired
Use this variant when the contract needs to represent recovery required; selecting it has no side effect by itself.