pub enum CapabilitySourceKind {
SdkBuiltIn,
HostProvided,
ToolPack,
McpServer,
Extension,
Subagent,
DiscoveryIndex,
TestOnlyFake,
}Expand description
Enumerates the finite capability source kind cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
SdkBuiltIn
Use this variant when the contract needs to represent sdk built in; selecting it has no side effect by itself.
HostProvided
Use this variant when the contract needs to represent host provided; selecting it has no side effect by itself.
ToolPack
Use this variant when the contract needs to represent tool pack; selecting it has no side effect by itself.
McpServer
Use this variant when the contract needs to represent mcp server; selecting it has no side effect by itself.
Extension
Use this variant when the contract needs to represent extension; selecting it has no side effect by itself.
Subagent
Use this variant when the contract needs to represent subagent; selecting it has no side effect by itself.
DiscoveryIndex
Use this variant when the contract needs to represent discovery index; selecting it has no side effect by itself.
TestOnlyFake
Use this variant when the contract needs to represent test only fake; selecting it has no side effect by itself.