pub enum ContentResolutionErrorKind {
Missing,
Expired,
PermissionDenied,
StorageUnavailable,
VersionMismatch,
HashMismatch,
UnsupportedMime,
RawContentNotAllowed,
MaxBytesExceeded,
}Expand description
Enumerates the finite content resolution error kind cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Missing
Use this variant when the contract needs to represent missing; selecting it has no side effect by itself.
Expired
Use this variant when the contract needs to represent expired; selecting it has no side effect by itself.
PermissionDenied
Use this variant when the contract needs to represent permission denied; selecting it has no side effect by itself.
Use this variant when the contract needs to represent storage unavailable; selecting it has no side effect by itself.
VersionMismatch
Use this variant when the contract needs to represent version mismatch; selecting it has no side effect by itself.
HashMismatch
Use this variant when the contract needs to represent hash mismatch; selecting it has no side effect by itself.
UnsupportedMime
Use this variant when the contract needs to represent unsupported mime; selecting it has no side effect by itself.
RawContentNotAllowed
Use this variant when the contract needs to represent raw content not allowed; selecting it has no side effect by itself.
MaxBytesExceeded
Use this variant when the contract needs to represent max bytes exceeded; selecting it has no side effect by itself.