pub enum ContentScope {
Run,
Session,
HostWorkspace,
External,
PersistentStore,
}Expand description
Enumerates the finite content scope cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Run
Use this variant when the contract needs to represent run; selecting it has no side effect by itself.
Session
Use this variant when the contract needs to represent session; selecting it has no side effect by itself.
HostWorkspace
Use this variant when the contract needs to represent host workspace; selecting it has no side effect by itself.
External
Use this variant when the contract needs to represent external; selecting it has no side effect by itself.
PersistentStore
Use this variant when the contract needs to represent persistent store; selecting it has no side effect by itself.