pub enum RetentionUse {
ReadOnly,
ProviderProjection,
Validation,
Delivery,
Replay,
}Expand description
Enumerates the finite retention use cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
ReadOnly
Use this variant when the contract needs to represent read only; selecting it has no side effect by itself.
ProviderProjection
Use this variant when the contract needs to represent provider projection; selecting it has no side effect by itself.
Validation
Use this variant when the contract needs to represent validation; selecting it has no side effect by itself.
Delivery
Use this variant when the contract needs to represent delivery; selecting it has no side effect by itself.
Replay
Use this variant when the contract needs to represent replay; selecting it has no side effect by itself.