pub enum ProjectionRole {
System,
Developer,
User,
AssistantContext,
ToolResult,
SchemaHint,
}Expand description
Enumerates the finite projection role cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
System
Use this variant when the contract needs to represent system; selecting it has no side effect by itself.
Developer
Use this variant when the contract needs to represent developer; selecting it has no side effect by itself.
User
Use this variant when the contract needs to represent user; selecting it has no side effect by itself.
AssistantContext
Use this variant when the contract needs to represent assistant context; selecting it has no side effect by itself.
ToolResult
Use this variant when the contract needs to represent tool result; selecting it has no side effect by itself.
SchemaHint
Use this variant when the contract needs to represent schema hint; selecting it has no side effect by itself.