pub enum EffectKind {
Show 15 variants
ProviderRequest,
ToolExecution,
ApprovalDispatch,
MemoryWrite,
ExtensionAction,
OutputDelivery,
FileWrite,
ProcessStart,
ProcessSignal,
IsolatedProcessStart,
ChildAgentStart,
RunMessageDelivery,
ChildArtifactShutdown,
DetachTransfer,
HookMutation,
}Expand description
Enumerates the finite effect kind cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
ProviderRequest
Use this variant when the contract needs to represent provider request; selecting it has no side effect by itself.
ToolExecution
Use this variant when the contract needs to represent tool execution; selecting it has no side effect by itself.
ApprovalDispatch
Use this variant when the contract needs to represent approval dispatch; selecting it has no side effect by itself.
MemoryWrite
Use this variant when the contract needs to represent memory write; selecting it has no side effect by itself.
ExtensionAction
Use this variant when the contract needs to represent extension action; selecting it has no side effect by itself.
OutputDelivery
Use this variant when the contract needs to represent output delivery; selecting it has no side effect by itself.
FileWrite
Use this variant when the contract needs to represent file write; selecting it has no side effect by itself.
ProcessStart
Use this variant when the contract needs to represent process start; selecting it has no side effect by itself.
ProcessSignal
Use this variant when the contract needs to represent process signal; selecting it has no side effect by itself.
IsolatedProcessStart
Use this variant when the contract needs to represent isolated process start; selecting it has no side effect by itself.
ChildAgentStart
Use this variant when the contract needs to represent child agent start; selecting it has no side effect by itself.
RunMessageDelivery
Use this variant when the contract needs to represent run message delivery; selecting it has no side effect by itself.
ChildArtifactShutdown
Use this variant when the contract needs to represent child artifact shutdown; selecting it has no side effect by itself.
DetachTransfer
Use this variant when the contract needs to represent detach transfer; selecting it has no side effect by itself.
HookMutation
Use this variant when the contract needs to represent hook mutation; selecting it has no side effect by itself.