pub enum EffectTerminalStatus {
Completed,
Failed,
TimedOut,
Cancelled,
DeniedBeforeExecution,
Unknown,
}Expand description
Enumerates the finite effect terminal status cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Completed
Use this variant when the contract needs to represent completed; selecting it has no side effect by itself.
Failed
Use this variant when the contract needs to represent failed; selecting it has no side effect by itself.
TimedOut
Use this variant when the contract needs to represent timed out; selecting it has no side effect by itself.
Cancelled
Use this variant when the contract needs to represent cancelled; selecting it has no side effect by itself.
DeniedBeforeExecution
Use this variant when the contract needs to represent denied before execution; selecting it has no side effect by itself.
Unknown
Use this variant when the contract needs to represent unknown; selecting it has no side effect by itself.