pub enum RetryClassification {
Retryable,
NotRetryable,
RepairNeeded,
UserActionNeeded,
HostConfigurationNeeded,
}Expand description
Enumerates the finite retry classification cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Retryable
Use this variant when the contract needs to represent retryable; selecting it has no side effect by itself.
NotRetryable
Use this variant when the contract needs to represent not retryable; selecting it has no side effect by itself.
RepairNeeded
Use this variant when the contract needs to represent repair needed; selecting it has no side effect by itself.
UserActionNeeded
Use this variant when the contract needs to represent user action needed; selecting it has no side effect by itself.
HostConfigurationNeeded
Use this variant when the contract needs to represent host configuration needed; selecting it has no side effect by itself.