pub enum EventDeliverySemantics {
BestEffortLive,
JournalBacked,
DerivedReplay,
DiagnosticOnly,
}Expand description
Enumerates the finite event delivery semantics cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
BestEffortLive
Use this variant when the contract needs to represent best effort live; selecting it has no side effect by itself.
JournalBacked
Use this variant when the contract needs to represent journal backed; selecting it has no side effect by itself.
DerivedReplay
Use this variant when the contract needs to represent derived replay; selecting it has no side effect by itself.
DiagnosticOnly
Use this variant when the contract needs to represent diagnostic only; selecting it has no side effect by itself.