pub enum EventFamily {
Show 20 variants
Run,
Turn,
Message,
Model,
Tool,
Approval,
Hook,
Context,
StreamRule,
Realtime,
Isolation,
ChildLifecycle,
AgentPool,
Subagent,
Extension,
StructuredOutput,
Output,
OutputDelivery,
Telemetry,
Recovery,
}Expand description
Enumerates the finite event family cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Run
Use this variant when the contract needs to represent run; selecting it has no side effect by itself.
Turn
Use this variant when the contract needs to represent turn; selecting it has no side effect by itself.
Message
Use this variant when the contract needs to represent message; selecting it has no side effect by itself.
Model
Use this variant when the contract needs to represent model; selecting it has no side effect by itself.
Tool
Use this variant when the contract needs to represent tool; selecting it has no side effect by itself.
Approval
Use this variant when the contract needs to represent approval; selecting it has no side effect by itself.
Hook
Use this variant when the contract needs to represent hook; selecting it has no side effect by itself.
Context
Use this variant when the contract needs to represent context; selecting it has no side effect by itself.
StreamRule
Use this variant when the contract needs to represent stream rule; selecting it has no side effect by itself.
Realtime
Use this variant when the contract needs to represent realtime; selecting it has no side effect by itself.
Isolation
Use this variant when the contract needs to represent isolation; selecting it has no side effect by itself.
ChildLifecycle
Use this variant when the contract needs to represent child lifecycle; selecting it has no side effect by itself.
AgentPool
Use this variant when the contract needs to represent agent pool; selecting it has no side effect by itself.
Subagent
Use this variant when the contract needs to represent subagent; selecting it has no side effect by itself.
Extension
Use this variant when the contract needs to represent extension; selecting it has no side effect by itself.
StructuredOutput
Use this variant when the contract needs to represent structured output; selecting it has no side effect by itself.
Output
Use this variant when the contract needs to represent output; selecting it has no side effect by itself.
OutputDelivery
Use this variant when the contract needs to represent output delivery; selecting it has no side effect by itself.
Telemetry
Use this variant when the contract needs to represent telemetry; selecting it has no side effect by itself.
Recovery
Use this variant when the contract needs to represent recovery; selecting it has no side effect by itself.