pub enum HookInvocationStatus {
Completed,
AppliedJournaledMutation,
RejectedMutationRight,
RejectedPointMatrix,
RejectedPolicy,
TimedOutFailOpen,
FailedOpen,
Cancelled,
}Expand description
Enumerates the finite hook invocation status cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Completed
Use this variant when the contract needs to represent completed; selecting it has no side effect by itself.
AppliedJournaledMutation
Use this variant when the contract needs to represent applied journaled mutation; selecting it has no side effect by itself.
RejectedMutationRight
Use this variant when the contract needs to represent rejected mutation right; selecting it has no side effect by itself.
RejectedPointMatrix
Use this variant when the contract needs to represent rejected point matrix; selecting it has no side effect by itself.
RejectedPolicy
Use this variant when the contract needs to represent rejected policy; selecting it has no side effect by itself.
TimedOutFailOpen
Use this variant when the contract needs to represent timed out fail open; selecting it has no side effect by itself.
FailedOpen
Use this variant when the contract needs to represent failed open; selecting it has no side effect by itself.
Cancelled
Use this variant when the contract needs to represent cancelled; selecting it has no side effect by itself.