IdValidationError

Enum IdValidationError 

pub enum IdValidationError {
    Empty,
    TooLong {
        max: usize,
        actual: usize,
    },
    ControlCharacter {
        index: usize,
    },
}
Enumerates the finite id validation error cases. Serialized names are part of the SDK contract; update fixtures when variants change.

Variants



Empty

Use this variant when the contract needs to represent empty; selecting it has no side effect by itself.



TooLong

Use this variant when the contract needs to represent too long; selecting it has no side effect by itself.

Fields

max: usize

Max used by this record or request.

actual: usize

Actual used by this record or request.



ControlCharacter

Use this variant when the contract needs to represent control character; selecting it has no side effect by itself.

Fields

index: usize

Index used by this record or request.