pub enum AgentPoolLifecycleStatus {
Created,
RunJoined,
RunLeft,
}Expand description
Enumerates the finite agent pool lifecycle status cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Created
Use this variant when the contract needs to represent created; selecting it has no side effect by itself.
RunJoined
Use this variant when the contract needs to represent run joined; selecting it has no side effect by itself.
RunLeft
Use this variant when the contract needs to represent run left; selecting it has no side effect by itself.