pub enum MaxIterationOutcome {
Complete,
Fail,
}Expand description
Enumerates the finite max iteration outcome cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Complete
Use this variant when the contract needs to represent complete; selecting it has no side effect by itself.
Fail
Use this variant when the contract needs to represent fail; selecting it has no side effect by itself.