pub enum SideEffectPolicy {
None,
IntentBeforeEffect,
IdempotentRetryAllowed,
NonIdempotentFailClosed,
ReconcileRequired,
}Expand description
Enumerates the finite side effect policy cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
None
Use this variant when the contract needs to represent none; selecting it has no side effect by itself.
IntentBeforeEffect
Use this variant when the contract needs to represent intent before effect; selecting it has no side effect by itself.
IdempotentRetryAllowed
Use this variant when the contract needs to represent idempotent retry allowed; selecting it has no side effect by itself.
NonIdempotentFailClosed
Use this variant when the contract needs to represent non idempotent fail closed; selecting it has no side effect by itself.
ReconcileRequired
Use this variant when the contract needs to represent reconcile required; selecting it has no side effect by itself.