pub fn transition_table() -> &'static [TransitionRule]Expand description
Returns the transition table derived from this value. This derives SDK state locally and does not call host adapters.
pub fn transition_table() -> &'static [TransitionRule]Returns the transition table derived from this value. This derives SDK state locally and does not call host adapters.