pub enum OutputSchemaDialect {
JsonSchema2020_12Subset,
RustSerdeTypeName,
HostRegistered,
}Expand description
Enumerates the finite output schema dialect cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
JsonSchema2020_12Subset
Use this variant when the contract needs to represent json schema2020 12 subset; selecting it has no side effect by itself.
RustSerdeTypeName
Use this variant when the contract needs to represent rust serde type name; selecting it has no side effect by itself.
HostRegistered
Use this variant when the contract needs to represent host registered; selecting it has no side effect by itself.