pub enum ProviderHintPolicy {
SchemaRequired,
SchemaOptional,
ProviderNativeHint,
}Expand description
Enumerates the finite provider hint policy cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
SchemaRequired
Use this variant when the contract needs to represent schema required; selecting it has no side effect by itself.
SchemaOptional
Use this variant when the contract needs to represent schema optional; selecting it has no side effect by itself.
ProviderNativeHint
Use this variant when the contract needs to represent provider native hint; selecting it has no side effect by itself.