pub enum OutputContentMode {
ContentRefsOnly,
RedactedSummary,
RawContentIfPolicyAllows,
}Expand description
Enumerates the finite output content mode cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
ContentRefsOnly
Use this variant when the contract needs to represent content refs only; selecting it has no side effect by itself.
RedactedSummary
Use this variant when the contract needs to represent redacted summary; selecting it has no side effect by itself.
RawContentIfPolicyAllows
Use this variant when the contract needs to represent raw content if policy allows; selecting it has no side effect by itself.