pub enum OutputDeliveryEventKind {
OutputDispatchRequested,
OutputDispatchCompleted,
OutputDispatchFailed,
OutputDispatchDeduped,
}Expand description
Enumerates the finite output delivery event kind cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
OutputDispatchRequested
Use this variant when the contract needs to represent output dispatch requested; selecting it has no side effect by itself.
OutputDispatchCompleted
Use this variant when the contract needs to represent output dispatch completed; selecting it has no side effect by itself.
OutputDispatchFailed
Use this variant when the contract needs to represent output dispatch failed; selecting it has no side effect by itself.
OutputDispatchDeduped
Use this variant when the contract needs to represent output dispatch deduped; selecting it has no side effect by itself.