OutputDispatchStatus

Enum OutputDispatchStatus 

pub enum OutputDispatchStatus {
    Requested,
    Completed,
    Failed,
    Deduped,
    HostConfigurationNeeded,
    PolicyDenied,
    SkippedOptional,
    ReconciliationNeeded,
}
Enumerates the finite output dispatch status cases. Serialized names are part of the SDK contract; update fixtures when variants change.

Variants



Requested

Use this variant when the contract needs to represent requested; selecting it has no side effect by itself.



Completed

Use this variant when the contract needs to represent completed; selecting it has no side effect by itself.



Failed

Use this variant when the contract needs to represent failed; selecting it has no side effect by itself.



Deduped

Use this variant when the contract needs to represent deduped; selecting it has no side effect by itself.



HostConfigurationNeeded

Use this variant when the contract needs to represent host configuration needed; selecting it has no side effect by itself.



PolicyDenied

Use this variant when the contract needs to represent policy denied; selecting it has no side effect by itself.



SkippedOptional

Use this variant when the contract needs to represent skipped optional; selecting it has no side effect by itself.



ReconciliationNeeded

Use this variant when the contract needs to represent reconciliation needed; selecting it has no side effect by itself.