pub enum TerminalAppendStatus {
NotAttempted,
Appended,
AppendFailed,
}Expand description
Enumerates the finite terminal append status cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
NotAttempted
Use this variant when the contract needs to represent not attempted; selecting it has no side effect by itself.
Appended
Use this variant when the contract needs to represent appended; selecting it has no side effect by itself.
AppendFailed
Use this variant when the contract needs to represent append failed; selecting it has no side effect by itself.