pub enum FingerprintExclusionGroup {
RunIds,
EventIds,
Timestamps,
AdapterHealth,
TemporaryPaths,
TelemetrySinkHealth,
}Expand description
Enumerates the finite fingerprint exclusion group cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
RunIds
Use this variant when the contract needs to represent run ids; selecting it has no side effect by itself.
EventIds
Use this variant when the contract needs to represent event ids; selecting it has no side effect by itself.
Timestamps
Use this variant when the contract needs to represent timestamps; selecting it has no side effect by itself.
AdapterHealth
Use this variant when the contract needs to represent adapter health; selecting it has no side effect by itself.
TemporaryPaths
Use this variant when the contract needs to represent temporary paths; selecting it has no side effect by itself.
TelemetrySinkHealth
Use this variant when the contract needs to represent telemetry sink health; selecting it has no side effect by itself.