pub enum RouteInheritanceMode {
InheritParent,
ExplicitOverrideOnly,
}Expand description
Enumerates the finite route inheritance mode cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
InheritParent
Use this variant when the contract needs to represent inherit parent; selecting it has no side effect by itself.
ExplicitOverrideOnly
Use this variant when the contract needs to represent explicit override only; selecting it has no side effect by itself.