pub enum ToolPackKind {
WorkspaceReadOnly,
WorkspaceSearch,
WorkspaceEdit,
WorkspaceWrite,
Shell,
ResourceReaders,
ToolDiscovery,
External,
}Expand description
Enumerates the finite tool pack kind cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
WorkspaceReadOnly
Use this variant when the contract needs to represent workspace read only; selecting it has no side effect by itself.
WorkspaceSearch
Use this variant when the contract needs to represent workspace search; selecting it has no side effect by itself.
WorkspaceEdit
Use this variant when the contract needs to represent workspace edit; selecting it has no side effect by itself.
WorkspaceWrite
Use this variant when the contract needs to represent workspace write; selecting it has no side effect by itself.
Shell
Use this variant when the contract needs to represent shell; selecting it has no side effect by itself.
ResourceReaders
Use this variant when the contract needs to represent resource readers; selecting it has no side effect by itself.
ToolDiscovery
Use this variant when the contract needs to represent tool discovery; selecting it has no side effect by itself.
External
Use this variant when the contract needs to represent external; selecting it has no side effect by itself.