pub enum HookOrderingPhase {
Early,
Normal,
Late,
}Expand description
Enumerates the finite hook ordering phase cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Early
Use this variant when the contract needs to represent early; selecting it has no side effect by itself.
Normal
Use this variant when the contract needs to represent normal; selecting it has no side effect by itself.
Late
Use this variant when the contract needs to represent late; selecting it has no side effect by itself.