pub enum ExecutionEnvironmentKind {
HostProcess,
Sandbox,
Container,
LightweightVm,
RemoteSandbox,
}Expand description
Enumerates the finite execution environment kind cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
HostProcess
Use this variant when the contract needs to represent host process; selecting it has no side effect by itself.
Sandbox
Use this variant when the contract needs to represent sandbox; selecting it has no side effect by itself.
Container
Use this variant when the contract needs to represent container; selecting it has no side effect by itself.
LightweightVm
Use this variant when the contract needs to represent lightweight vm; selecting it has no side effect by itself.
RemoteSandbox
Use this variant when the contract needs to represent remote sandbox; selecting it has no side effect by itself.