IsolationTrustField

Enum IsolationTrustField 

pub enum IsolationTrustField {
    Locality,
    Tenancy,
    Auditability,
    Cleanup,
    DataResidency,
    SecretIsolation,
}
Enumerates the finite isolation trust field cases. Serialized names are part of the SDK contract; update fixtures when variants change.

Variants



Locality

Use this variant when the contract needs to represent locality; selecting it has no side effect by itself.



Tenancy

Use this variant when the contract needs to represent tenancy; selecting it has no side effect by itself.



Auditability

Use this variant when the contract needs to represent auditability; selecting it has no side effect by itself.



Cleanup

Use this variant when the contract needs to represent cleanup; selecting it has no side effect by itself.



DataResidency

Use this variant when the contract needs to represent data residency; selecting it has no side effect by itself.



SecretIsolation

Use this variant when the contract needs to represent secret isolation; selecting it has no side effect by itself.