pub enum ProcessContentCaptureMode {
Off,
MetadataOnly,
RedactedSummary,
ContentRef,
RawContentIfPolicyAllows,
}Expand description
Enumerates the finite process content capture mode cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Off
Use this variant when the contract needs to represent off; selecting it has no side effect by itself.
MetadataOnly
Use this variant when the contract needs to represent metadata only; selecting it has no side effect by itself.
RedactedSummary
Use this variant when the contract needs to represent redacted summary; selecting it has no side effect by itself.
ContentRef
Use this variant when the contract needs to represent content ref; selecting it has no side effect by itself.
RawContentIfPolicyAllows
Use this variant when the contract needs to represent raw content if policy allows; selecting it has no side effect by itself.