pub enum ProcessOwnershipClass {
AgentOwned,
HostManaged,
DetachedByIntent,
}Expand description
Enumerates the finite process ownership class cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
AgentOwned
Use this variant when the contract needs to represent agent owned; selecting it has no side effect by itself.
HostManaged
Use this variant when the contract needs to represent host managed; selecting it has no side effect by itself.
DetachedByIntent
Use this variant when the contract needs to represent detached by intent; selecting it has no side effect by itself.