pub enum RootFilesystemMode {
ReadOnly,
WritableLayer,
}Expand description
Enumerates the finite root filesystem mode cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
ReadOnly
Use this variant when the contract needs to represent read only; selecting it has no side effect by itself.
WritableLayer
Use this variant when the contract needs to represent writable layer; selecting it has no side effect by itself.