pub enum SecretIsolationRequirement {
None,
BestEffort,
Required,
}Expand description
Enumerates the finite secret isolation requirement cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
None
Use this variant when the contract needs to represent none; selecting it has no side effect by itself.
BestEffort
Use this variant when the contract needs to represent best effort; selecting it has no side effect by itself.
Required
Use this variant when the contract needs to represent required; selecting it has no side effect by itself.