pub enum SymlinkPolicy {
DenyEscapes,
FollowWithinAlias,
}Expand description
Enumerates the finite symlink policy cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
DenyEscapes
Use this variant when the contract needs to represent deny escapes; selecting it has no side effect by itself.
FollowWithinAlias
Use this variant when the contract needs to represent follow within alias; selecting it has no side effect by itself.