pub enum TenantBoundaryRequirement {
SharedAllowed,
Dedicated,
}Expand description
Enumerates the finite tenant boundary requirement cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Use this variant when the contract needs to represent shared allowed; selecting it has no side effect by itself.
Dedicated
Use this variant when the contract needs to represent dedicated; selecting it has no side effect by itself.