pub enum DispatcherScope {
Host,
SourceScoped,
Headless,
}Expand description
Enumerates the finite dispatcher scope cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Host
Use this variant when the contract needs to represent host; selecting it has no side effect by itself.
SourceScoped
Use this variant when the contract needs to represent source scoped; selecting it has no side effect by itself.
Headless
Use this variant when the contract needs to represent headless; selecting it has no side effect by itself.