pub enum IsolationRuntimeKind {
HostProvided,
HostProcess,
OsSandbox,
Container,
LightweightVm,
RemoteSandbox,
TestOnlyFake,
}Expand description
Enumerates the finite isolation runtime kind cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
HostProvided
Use this variant when the contract needs to represent host provided; selecting it has no side effect by itself.
HostProcess
Use this variant when the contract needs to represent host process; selecting it has no side effect by itself.
OsSandbox
Use this variant when the contract needs to represent os sandbox; selecting it has no side effect by itself.
Container
Use this variant when the contract needs to represent container; selecting it has no side effect by itself.
LightweightVm
Use this variant when the contract needs to represent lightweight vm; selecting it has no side effect by itself.
RemoteSandbox
Use this variant when the contract needs to represent remote sandbox; selecting it has no side effect by itself.
TestOnlyFake
Use this variant when the contract needs to represent test only fake; selecting it has no side effect by itself.