pub enum ProcessIoStream {
Stdin,
Stdout,
Stderr,
}Expand description
Enumerates the finite process io stream cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Stdin
Use this variant when the contract needs to represent stdin; selecting it has no side effect by itself.
Stdout
Use this variant when the contract needs to represent stdout; selecting it has no side effect by itself.
Stderr
Use this variant when the contract needs to represent stderr; selecting it has no side effect by itself.