pub enum RetentionClass {
Ephemeral,
RunScoped,
SessionScoped,
Durable,
Persistent,
HostPolicy,
}Expand description
Enumerates the finite retention class cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Ephemeral
Use this variant when the contract needs to represent ephemeral; selecting it has no side effect by itself.
RunScoped
Use this variant when the contract needs to represent run scoped; selecting it has no side effect by itself.
SessionScoped
Use this variant when the contract needs to represent session scoped; selecting it has no side effect by itself.
Durable
Use this variant when the contract needs to represent durable; selecting it has no side effect by itself.
Persistent
Use this variant when the contract needs to represent persistent; selecting it has no side effect by itself.
HostPolicy
Use this variant when the contract needs to represent host policy; selecting it has no side effect by itself.