pub enum TrustClass {
Trusted,
SdkGenerated,
HostProvided,
UserProvided,
External,
Untrusted,
}Expand description
Enumerates the finite trust class cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Trusted
Use this variant when the contract needs to represent trusted; selecting it has no side effect by itself.
SdkGenerated
Use this variant when the contract needs to represent sdk generated; selecting it has no side effect by itself.
HostProvided
Use this variant when the contract needs to represent host provided; selecting it has no side effect by itself.
UserProvided
Use this variant when the contract needs to represent user provided; selecting it has no side effect by itself.
External
Use this variant when the contract needs to represent external; selecting it has no side effect by itself.
Untrusted
Use this variant when the contract needs to represent untrusted; selecting it has no side effect by itself.