pub enum ProviderMessageRole {
System,
Developer,
User,
Assistant,
Tool,
Context,
}Expand description
Enumerates the finite provider message role cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
System
Use this variant when the contract needs to represent system; selecting it has no side effect by itself.
Developer
Use this variant when the contract needs to represent developer; selecting it has no side effect by itself.
User
Use this variant when the contract needs to represent user; selecting it has no side effect by itself.
Assistant
Use this variant when the contract needs to represent assistant; selecting it has no side effect by itself.
Tool
Use this variant when the contract needs to represent tool; selecting it has no side effect by itself.
Context
Use this variant when the contract needs to represent context; selecting it has no side effect by itself.