pub enum RealtimeCloseReason {
Normal,
Cancel,
ProviderFailure,
PolicyDenial,
HostOwnedDetach,
}Expand description
Enumerates the finite realtime close reason cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Normal
Use this variant when the contract needs to represent normal; selecting it has no side effect by itself.
Cancel
Use this variant when the contract needs to represent cancel; selecting it has no side effect by itself.
ProviderFailure
Use this variant when the contract needs to represent provider failure; selecting it has no side effect by itself.
PolicyDenial
Use this variant when the contract needs to represent policy denial; selecting it has no side effect by itself.
HostOwnedDetach
Use this variant when the contract needs to represent host owned detach; selecting it has no side effect by itself.