pub enum RealtimeSessionRecordKind {
Show 15 variants
ConnectRequested,
Connected,
InputSendRequested,
InputSent,
OutputReceiveRequested,
OutputReceived,
InterruptRequested,
Interrupted,
RestartRequested,
RestartStarted,
RestartCompleted,
RestartFailed,
CloseRequested,
Closed,
BackpressureApplied,
}Expand description
Enumerates the finite realtime session record kind cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
ConnectRequested
Use this variant when the contract needs to represent connect requested; selecting it has no side effect by itself.
Connected
Use this variant when the contract needs to represent connected; selecting it has no side effect by itself.
InputSendRequested
Use this variant when the contract needs to represent input send requested; selecting it has no side effect by itself.
InputSent
Use this variant when the contract needs to represent input sent; selecting it has no side effect by itself.
OutputReceiveRequested
Use this variant when the contract needs to represent output receive requested; selecting it has no side effect by itself.
OutputReceived
Use this variant when the contract needs to represent output received; selecting it has no side effect by itself.
InterruptRequested
Use this variant when the contract needs to represent interrupt requested; selecting it has no side effect by itself.
Interrupted
Use this variant when the contract needs to represent interrupted; selecting it has no side effect by itself.
RestartRequested
Use this variant when the contract needs to represent restart requested; selecting it has no side effect by itself.
RestartStarted
Use this variant when the contract needs to represent restart started; selecting it has no side effect by itself.
RestartCompleted
Use this variant when the contract needs to represent restart completed; selecting it has no side effect by itself.
RestartFailed
Use this variant when the contract needs to represent restart failed; selecting it has no side effect by itself.
CloseRequested
Use this variant when the contract needs to represent close requested; selecting it has no side effect by itself.
Closed
Use this variant when the contract needs to represent closed; selecting it has no side effect by itself.
BackpressureApplied
Use this variant when the contract needs to represent backpressure applied; selecting it has no side effect by itself.