EntityKind

Enum EntityKind 

pub enum EntityKind {
Show 31 variants Run, Turn, Attempt, Agent, AgentPool, Topic, Event, Message, WakeCondition, ContextContribution, ContextItem, ContextProjection, Content, Artifact, Capability, PackageSidecar, RuntimePackage, PolicyDecision, Effect, EffectIntent, EffectResult, ToolCall, ApprovalRequest, StreamRule, RealtimeSession, Hook, ExecutionEnvironment, ChildArtifact, SubagentRun, ExtensionAction, OutputDelivery,
}
Enumerates the finite entity kind cases. Serialized names are part of the SDK contract; update fixtures when variants change.

Variants



Run

Use this variant when the contract needs to represent run; selecting it has no side effect by itself.



Turn

Use this variant when the contract needs to represent turn; selecting it has no side effect by itself.



Attempt

Use this variant when the contract needs to represent attempt; selecting it has no side effect by itself.



Agent

Use this variant when the contract needs to represent agent; selecting it has no side effect by itself.



AgentPool

Use this variant when the contract needs to represent agent pool; selecting it has no side effect by itself.



Topic

Use this variant when the contract needs to represent topic; selecting it has no side effect by itself.



Event

Use this variant when the contract needs to represent event; selecting it has no side effect by itself.



Message

Use this variant when the contract needs to represent message; selecting it has no side effect by itself.



WakeCondition

Use this variant when the contract needs to represent wake condition; selecting it has no side effect by itself.



ContextContribution

Use this variant when the contract needs to represent context contribution; selecting it has no side effect by itself.



ContextItem

Use this variant when the contract needs to represent context item; selecting it has no side effect by itself.



ContextProjection

Use this variant when the contract needs to represent context projection; selecting it has no side effect by itself.



Content

Use this variant when the contract needs to represent content; selecting it has no side effect by itself.



Artifact

Use this variant when the contract needs to represent artifact; selecting it has no side effect by itself.



Capability

Use this variant when the contract needs to represent capability; selecting it has no side effect by itself.



PackageSidecar

Use this variant when the contract needs to represent package sidecar; selecting it has no side effect by itself.



RuntimePackage

Use this variant when the contract needs to represent runtime package; selecting it has no side effect by itself.



PolicyDecision

Use this variant when the contract needs to represent policy decision; selecting it has no side effect by itself.



Effect

Use this variant when the contract needs to represent effect; selecting it has no side effect by itself.



EffectIntent

Use this variant when the contract needs to represent effect intent; selecting it has no side effect by itself.



EffectResult

Use this variant when the contract needs to represent effect result; selecting it has no side effect by itself.



ToolCall

Use this variant when the contract needs to represent tool call; selecting it has no side effect by itself.



ApprovalRequest

Use this variant when the contract needs to represent approval request; selecting it has no side effect by itself.



StreamRule

Use this variant when the contract needs to represent stream rule; selecting it has no side effect by itself.



RealtimeSession

Use this variant when the contract needs to represent realtime session; selecting it has no side effect by itself.



Hook

Use this variant when the contract needs to represent hook; selecting it has no side effect by itself.



ExecutionEnvironment

Use this variant when the contract needs to represent execution environment; selecting it has no side effect by itself.



ChildArtifact

Use this variant when the contract needs to represent child artifact; selecting it has no side effect by itself.



SubagentRun

Use this variant when the contract needs to represent subagent run; selecting it has no side effect by itself.



ExtensionAction

Use this variant when the contract needs to represent extension action; selecting it has no side effect by itself.



OutputDelivery

Use this variant when the contract needs to represent output delivery; selecting it has no side effect by itself.