pub enum PolicyKind {
Approval,
Permission,
Sandbox,
Context,
Privacy,
Retention,
Redaction,
RuntimePackage,
Host,
}Expand description
Enumerates the finite policy kind cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Approval
Use this variant when the contract needs to represent approval; selecting it has no side effect by itself.
Permission
Use this variant when the contract needs to represent permission; selecting it has no side effect by itself.
Sandbox
Use this variant when the contract needs to represent sandbox; selecting it has no side effect by itself.
Context
Use this variant when the contract needs to represent context; selecting it has no side effect by itself.
Privacy
Use this variant when the contract needs to represent privacy; selecting it has no side effect by itself.
Retention
Use this variant when the contract needs to represent retention; selecting it has no side effect by itself.
Redaction
Use this variant when the contract needs to represent redaction; selecting it has no side effect by itself.
RuntimePackage
Use this variant when the contract needs to represent runtime package; selecting it has no side effect by itself.
Host
Use this variant when the contract needs to represent host; selecting it has no side effect by itself.