pub enum SourceKind {
Show 15 variants
Sdk,
Host,
User,
System,
Developer,
Memory,
Compaction,
Hook,
Extension,
Tool,
RemoteChannel,
ScheduledTask,
Subagent,
ExternalRuntime,
Replay,
}Expand description
Enumerates the finite source kind cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Sdk
Use this variant when the contract needs to represent sdk; selecting it has no side effect by itself.
Host
Use this variant when the contract needs to represent host; selecting it has no side effect by itself.
User
Use this variant when the contract needs to represent user; selecting it has no side effect by itself.
System
Use this variant when the contract needs to represent system; selecting it has no side effect by itself.
Developer
Use this variant when the contract needs to represent developer; selecting it has no side effect by itself.
Memory
Use this variant when the contract needs to represent memory; selecting it has no side effect by itself.
Compaction
Use this variant when the contract needs to represent compaction; selecting it has no side effect by itself.
Hook
Use this variant when the contract needs to represent hook; selecting it has no side effect by itself.
Extension
Use this variant when the contract needs to represent extension; selecting it has no side effect by itself.
Tool
Use this variant when the contract needs to represent tool; selecting it has no side effect by itself.
RemoteChannel
Use this variant when the contract needs to represent remote channel; selecting it has no side effect by itself.
ScheduledTask
Use this variant when the contract needs to represent scheduled task; selecting it has no side effect by itself.
Subagent
Use this variant when the contract needs to represent subagent; selecting it has no side effect by itself.
ExternalRuntime
Use this variant when the contract needs to represent external runtime; selecting it has no side effect by itself.
Replay
Use this variant when the contract needs to represent replay; selecting it has no side effect by itself.