pub enum ReplayStatus {
Complete,
RepairNeeded,
}Expand description
Enumerates the finite replay status cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Complete
Use this variant when the contract needs to represent complete; selecting it has no side effect by itself.
RepairNeeded
Use this variant when the contract needs to represent repair needed; selecting it has no side effect by itself.