pub enum RepeatPolicy {
Always,
OncePerRun,
OncePerTurn,
OncePerAttemptAndSpan,
}Expand description
Enumerates the finite repeat policy cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Always
Use this variant when the contract needs to represent always; selecting it has no side effect by itself.
OncePerRun
Use this variant when the contract needs to represent once per run; selecting it has no side effect by itself.
OncePerTurn
Use this variant when the contract needs to represent once per turn; selecting it has no side effect by itself.
OncePerAttemptAndSpan
Use this variant when the contract needs to represent once per attempt and span; selecting it has no side effect by itself.