pub enum StreamCursorPrecision {
ByteOffset,
ChunkSequenceOnly,
Marker,
}Expand description
Enumerates the finite stream cursor precision cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
ByteOffset
Use this variant when the contract needs to represent byte offset; selecting it has no side effect by itself.
ChunkSequenceOnly
Use this variant when the contract needs to represent chunk sequence only; selecting it has no side effect by itself.
Marker
Use this variant when the contract needs to represent marker; selecting it has no side effect by itself.