pub enum StreamDirection {
InputToProvider,
OutputFromProvider,
}Expand description
Enumerates the finite stream direction cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
InputToProvider
Use this variant when the contract needs to represent input to provider; selecting it has no side effect by itself.
OutputFromProvider
Use this variant when the contract needs to represent output from provider; selecting it has no side effect by itself.