pub enum StreamRuleRecordKind {
Registered,
CompileFailed,
Matched,
InterventionIntent,
InterventionResult,
RepeatState,
}Expand description
Enumerates the finite stream rule record kind cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Registered
Use this variant when the contract needs to represent registered; selecting it has no side effect by itself.
CompileFailed
Use this variant when the contract needs to represent compile failed; selecting it has no side effect by itself.
Matched
Use this variant when the contract needs to represent matched; selecting it has no side effect by itself.
InterventionIntent
Use this variant when the contract needs to represent intervention intent; selecting it has no side effect by itself.
InterventionResult
Use this variant when the contract needs to represent intervention result; selecting it has no side effect by itself.
RepeatState
Use this variant when the contract needs to represent repeat state; selecting it has no side effect by itself.