pub enum StreamRuleScope {
Run,
Turn,
Attempt,
RealtimeSession,
}Expand description
Enumerates the finite stream rule scope cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Run
Use this variant when the contract needs to represent run; selecting it has no side effect by itself.
Turn
Use this variant when the contract needs to represent turn; selecting it has no side effect by itself.
Attempt
Use this variant when the contract needs to represent attempt; selecting it has no side effect by itself.
RealtimeSession
Use this variant when the contract needs to represent realtime session; selecting it has no side effect by itself.