pub enum StructuredOutputLifecycleKind {
Requested,
ValidationStarted,
}Expand description
Enumerates the finite structured output lifecycle kind cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Requested
Use this variant when the contract needs to represent requested; selecting it has no side effect by itself.
ValidationStarted
Use this variant when the contract needs to represent validation started; selecting it has no side effect by itself.