pub enum ValidationErrorCode {
Show 13 variants
CandidateTooLarge,
InvalidJson,
UnsupportedDialect,
UnsupportedSchemaRef,
SchemaContractViolation,
HostileSchema,
MissingRequiredField,
TypeMismatch,
AdditionalPropertyDenied,
EnumMismatch,
MinLengthViolation,
MaxLengthViolation,
SemanticValidatorUnavailable,
}Expand description
Enumerates the finite validation error code cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
CandidateTooLarge
Use this variant when the contract needs to represent candidate too large; selecting it has no side effect by itself.
InvalidJson
Use this variant when the contract needs to represent invalid json; selecting it has no side effect by itself.
UnsupportedDialect
Use this variant when the contract needs to represent unsupported dialect; selecting it has no side effect by itself.
UnsupportedSchemaRef
Use this variant when the contract needs to represent unsupported schema ref; selecting it has no side effect by itself.
SchemaContractViolation
Use this variant when the contract needs to represent schema contract violation; selecting it has no side effect by itself.
HostileSchema
Use this variant when the contract needs to represent hostile schema; selecting it has no side effect by itself.
MissingRequiredField
Use this variant when the contract needs to represent missing required field; selecting it has no side effect by itself.
TypeMismatch
Use this variant when the contract needs to represent type mismatch; selecting it has no side effect by itself.
AdditionalPropertyDenied
Use this variant when the contract needs to represent additional property denied; selecting it has no side effect by itself.
EnumMismatch
Use this variant when the contract needs to represent enum mismatch; selecting it has no side effect by itself.
MinLengthViolation
Use this variant when the contract needs to represent min length violation; selecting it has no side effect by itself.
MaxLengthViolation
Use this variant when the contract needs to represent max length violation; selecting it has no side effect by itself.
Use this variant when the contract needs to represent semantic validator unavailable; selecting it has no side effect by itself.