pub enum ValidationRecordKind {
ValidationSucceeded,
ValidationFailed,
SchemaRejected,
TerminalFailure,
}Expand description
Enumerates the finite validation record kind cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
ValidationSucceeded
Use this variant when the contract needs to represent validation succeeded; selecting it has no side effect by itself.
ValidationFailed
Use this variant when the contract needs to represent validation failed; selecting it has no side effect by itself.
SchemaRejected
Use this variant when the contract needs to represent schema rejected; selecting it has no side effect by itself.
TerminalFailure
Use this variant when the contract needs to represent terminal failure; selecting it has no side effect by itself.