pub enum ChildLifecycleAction {
ShutdownIntent,
ShutdownCompleted,
DetachIntent,
Detached,
}Expand description
Enumerates the finite child lifecycle action cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
ShutdownIntent
Use this variant when the contract needs to represent shutdown intent; selecting it has no side effect by itself.
ShutdownCompleted
Use this variant when the contract needs to represent shutdown completed; selecting it has no side effect by itself.
DetachIntent
Use this variant when the contract needs to represent detach intent; selecting it has no side effect by itself.
Detached
Use this variant when the contract needs to represent detached; selecting it has no side effect by itself.