pub enum TelemetryContentCaptureMode {
Off,
MetadataOnly,
RedactedSummary,
PayloadRefs,
RawContent,
}Expand description
Enumerates the finite telemetry content capture mode cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Off
Use this variant when the contract needs to represent off; selecting it has no side effect by itself.
MetadataOnly
Use this variant when the contract needs to represent metadata only; selecting it has no side effect by itself.
RedactedSummary
Use this variant when the contract needs to represent redacted summary; selecting it has no side effect by itself.
PayloadRefs
Use this variant when the contract needs to represent payload refs; selecting it has no side effect by itself.
RawContent
Use this variant when the contract needs to represent raw content; selecting it has no side effect by itself.
Implementations
Sourceimpl TelemetryContentCaptureMode
impl TelemetryContentCaptureMode
Sourcepub fn captures_raw_content(&self) -> bool
pub fn captures_raw_content(&self) -> bool
Returns whether captures raw content applies for this contract. This is data-only and does not perform I/O, call host ports, append journals, publish events, or start processes.