pub enum TelemetrySinkFailureKind {
Overflow,
ExportRejected,
Serialization,
SchemaMismatch,
SinkUnavailable,
}Expand description
Enumerates the finite telemetry sink failure kind cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Overflow
Use this variant when the contract needs to represent overflow; selecting it has no side effect by itself.
ExportRejected
Use this variant when the contract needs to represent export rejected; selecting it has no side effect by itself.
Serialization
Use this variant when the contract needs to represent serialization; selecting it has no side effect by itself.
SchemaMismatch
Use this variant when the contract needs to represent schema mismatch; selecting it has no side effect by itself.
Use this variant when the contract needs to represent sink unavailable; selecting it has no side effect by itself.