pub enum TelemetrySinkHealthState {
Healthy,
Failed,
Recovered,
}Expand description
Enumerates the finite telemetry sink health state cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Healthy
Use this variant when the contract needs to represent healthy; selecting it has no side effect by itself.
Failed
Use this variant when the contract needs to represent failed; selecting it has no side effect by itself.
Recovered
Use this variant when the contract needs to represent recovered; selecting it has no side effect by itself.