pub enum TelemetrySourceCursor {
Journal(JournalCursor),
Event(EventCursor),
Archive(String),
Usage(TelemetryUsageRecordId),
Cost(TelemetryCostRecordId),
}Expand description
Enumerates the finite telemetry source cursor cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Journal(JournalCursor)
Use this variant when the contract needs to represent journal; selecting it has no side effect by itself.
Event(EventCursor)
Use this variant when the contract needs to represent event; selecting it has no side effect by itself.
Archive(String)
Use this variant when the contract needs to represent archive; selecting it has no side effect by itself.
Usage(TelemetryUsageRecordId)
Use this variant when the contract needs to represent usage; selecting it has no side effect by itself.
Cost(TelemetryCostRecordId)
Use this variant when the contract needs to represent cost; selecting it has no side effect by itself.