pub enum ToolExecutionStrategy {
Sequential,
BoundedConcurrent {
max_in_flight: usize,
},
OrderedBatch {
max_in_flight: usize,
},
}Expand description
Enumerates the finite tool execution strategy cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Sequential
Use this variant when the contract needs to represent sequential; selecting it has no side effect by itself.
BoundedConcurrent
Use this variant when the contract needs to represent bounded concurrent; selecting it has no side effect by itself.
OrderedBatch
Use this variant when the contract needs to represent ordered batch; selecting it has no side effect by itself.