pub enum ToolCallRecordStatus {
Requested,
IntentRecorded,
Completed,
Failed,
TimedOut,
Cancelled,
DeniedBeforeExecution,
Unknown,
RecoveryRequired,
}Expand description
Enumerates the finite tool call record status cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Requested
Use this variant when the contract needs to represent requested; selecting it has no side effect by itself.
IntentRecorded
Use this variant when the contract needs to represent intent recorded; selecting it has no side effect by itself.
Completed
Use this variant when the contract needs to represent completed; selecting it has no side effect by itself.
Failed
Use this variant when the contract needs to represent failed; selecting it has no side effect by itself.
TimedOut
Use this variant when the contract needs to represent timed out; selecting it has no side effect by itself.
Cancelled
Use this variant when the contract needs to represent cancelled; selecting it has no side effect by itself.
DeniedBeforeExecution
Use this variant when the contract needs to represent denied before execution; selecting it has no side effect by itself.
Unknown
Use this variant when the contract needs to represent unknown; selecting it has no side effect by itself.
RecoveryRequired
Use this variant when the contract needs to represent recovery required; selecting it has no side effect by itself.