pub enum AgentErrorKind {
Show 20 variants
InvalidPackage,
InvalidStateTransition,
ProviderFailure,
ProjectionFailure,
ToolFailure,
ApprovalFailure,
PolicyDenial,
JournalFailure,
TelemetryFailure,
IsolationFailure,
StructuredOutputFailure,
StreamRuleFailure,
SubagentFailure,
ExtensionFailure,
Cancellation,
ChildLifecycleFailure,
HookFailure,
Timeout,
RecoveryRepairNeeded,
HostConfigurationNeeded,
}Expand description
Enumerates the finite agent error kind cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
InvalidPackage
Use this variant when the contract needs to represent invalid package; selecting it has no side effect by itself.
InvalidStateTransition
Use this variant when the contract needs to represent invalid state transition; selecting it has no side effect by itself.
ProviderFailure
Use this variant when the contract needs to represent provider failure; selecting it has no side effect by itself.
ProjectionFailure
Use this variant when the contract needs to represent projection failure; selecting it has no side effect by itself.
ToolFailure
Use this variant when the contract needs to represent tool failure; selecting it has no side effect by itself.
ApprovalFailure
Use this variant when the contract needs to represent approval failure; selecting it has no side effect by itself.
PolicyDenial
Use this variant when the contract needs to represent policy denial; selecting it has no side effect by itself.
JournalFailure
Use this variant when the contract needs to represent journal failure; selecting it has no side effect by itself.
TelemetryFailure
Use this variant when the contract needs to represent telemetry failure; selecting it has no side effect by itself.
IsolationFailure
Use this variant when the contract needs to represent isolation failure; selecting it has no side effect by itself.
StructuredOutputFailure
Use this variant when the contract needs to represent structured output failure; selecting it has no side effect by itself.
StreamRuleFailure
Use this variant when the contract needs to represent stream rule failure; selecting it has no side effect by itself.
SubagentFailure
Use this variant when the contract needs to represent subagent failure; selecting it has no side effect by itself.
ExtensionFailure
Use this variant when the contract needs to represent extension failure; selecting it has no side effect by itself.
Cancellation
Use this variant when the contract needs to represent cancellation; selecting it has no side effect by itself.
ChildLifecycleFailure
Use this variant when the contract needs to represent child lifecycle failure; selecting it has no side effect by itself.
HookFailure
Use this variant when the contract needs to represent hook failure; selecting it has no side effect by itself.
Timeout
Use this variant when the contract needs to represent timeout; selecting it has no side effect by itself.
RecoveryRepairNeeded
Use this variant when the contract needs to represent recovery repair needed; selecting it has no side effect by itself.
HostConfigurationNeeded
Use this variant when the contract needs to represent host configuration needed; selecting it has no side effect by itself.