pub enum IdValidationError {
Empty,
TooLong {
max: usize,
actual: usize,
},
ControlCharacter {
index: usize,
},
}Expand description
Enumerates the finite id validation error cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Empty
Use this variant when the contract needs to represent empty; selecting it has no side effect by itself.
TooLong
Use this variant when the contract needs to represent too long; selecting it has no side effect by itself.
Fields
ControlCharacter
Use this variant when the contract needs to represent control character; selecting it has no side effect by itself.