pub enum LoopEventKind {
Show 28 variants
RunStarted,
RunCompleted,
RunFailed,
RunCancelled,
RunCancelRequested,
RunCheckpointed,
RunResumeRequested,
RunResumeFailed,
ContextAssembled,
ProviderRequestProjected,
ModelAttemptStarted,
ModelAttemptFailed,
ModelMessageCompleted,
ToolRequested,
ToolApprovalRequired,
ToolStarted,
ToolCompleted,
ToolFailed,
ToolInterrupted,
ApprovalRequested,
ApprovalResponded,
ApprovalTimedOut,
ApprovalDenied,
StreamRuleMatched,
StreamInterventionApplied,
ContextCompactionCompleted,
RecoveryPlanned,
ReplayCompleted,
}Expand description
Enumerates the finite loop event kind cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
RunStarted
Use this variant when the contract needs to represent run started; selecting it has no side effect by itself.
RunCompleted
Use this variant when the contract needs to represent run completed; selecting it has no side effect by itself.
RunFailed
Use this variant when the contract needs to represent run failed; selecting it has no side effect by itself.
RunCancelled
Use this variant when the contract needs to represent run cancelled; selecting it has no side effect by itself.
RunCancelRequested
Use this variant when the contract needs to represent run cancel requested; selecting it has no side effect by itself.
RunCheckpointed
Use this variant when the contract needs to represent run checkpointed; selecting it has no side effect by itself.
RunResumeRequested
Use this variant when the contract needs to represent run resume requested; selecting it has no side effect by itself.
RunResumeFailed
Use this variant when the contract needs to represent run resume failed; selecting it has no side effect by itself.
ContextAssembled
Use this variant when the contract needs to represent context assembled; selecting it has no side effect by itself.
ProviderRequestProjected
Use this variant when the contract needs to represent provider request projected; selecting it has no side effect by itself.
ModelAttemptStarted
Use this variant when the contract needs to represent model attempt started; selecting it has no side effect by itself.
ModelAttemptFailed
Use this variant when the contract needs to represent model attempt failed; selecting it has no side effect by itself.
ModelMessageCompleted
Use this variant when the contract needs to represent model message completed; selecting it has no side effect by itself.
ToolRequested
Use this variant when the contract needs to represent tool requested; selecting it has no side effect by itself.
ToolApprovalRequired
Use this variant when the contract needs to represent tool approval required; selecting it has no side effect by itself.
ToolStarted
Use this variant when the contract needs to represent tool started; selecting it has no side effect by itself.
ToolCompleted
Use this variant when the contract needs to represent tool completed; selecting it has no side effect by itself.
ToolFailed
Use this variant when the contract needs to represent tool failed; selecting it has no side effect by itself.
ToolInterrupted
Use this variant when the contract needs to represent tool interrupted; selecting it has no side effect by itself.
ApprovalRequested
Use this variant when the contract needs to represent approval requested; selecting it has no side effect by itself.
ApprovalResponded
Use this variant when the contract needs to represent approval responded; selecting it has no side effect by itself.
ApprovalTimedOut
Use this variant when the contract needs to represent approval timed out; selecting it has no side effect by itself.
ApprovalDenied
Use this variant when the contract needs to represent approval denied; selecting it has no side effect by itself.
StreamRuleMatched
Use this variant when the contract needs to represent stream rule matched; selecting it has no side effect by itself.
StreamInterventionApplied
Use this variant when the contract needs to represent stream intervention applied; selecting it has no side effect by itself.
ContextCompactionCompleted
Use this variant when the contract needs to represent context compaction completed; selecting it has no side effect by itself.
RecoveryPlanned
Use this variant when the contract needs to represent recovery planned; selecting it has no side effect by itself.
ReplayCompleted
Use this variant when the contract needs to represent replay completed; selecting it has no side effect by itself.