pub enum LoopStopReason {
Show 14 variants
EndTurn,
StreamRuleStop,
MaxIterations {
outcome: MaxIterationOutcome,
},
Cancelled,
ProviderFailure,
UnsafeStreamIntervention,
ToolDenied,
ApprovalDenied,
ApprovalTimeout,
ApprovalTransportFatal,
ToolFailure,
ResumeDenied,
RecoveryCompleted,
RecoveryIrrecoverable,
}Expand description
Enumerates the finite loop stop reason cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
EndTurn
Use this variant when the contract needs to represent end turn; selecting it has no side effect by itself.
StreamRuleStop
Use this variant when the contract needs to represent stream rule stop; selecting it has no side effect by itself.
MaxIterations
Use this variant when the contract needs to represent max iterations; selecting it has no side effect by itself.
Fields
outcome: MaxIterationOutcomeOutcome used by this record or request.
Cancelled
Use this variant when the contract needs to represent cancelled; selecting it has no side effect by itself.
ProviderFailure
Use this variant when the contract needs to represent provider failure; selecting it has no side effect by itself.
UnsafeStreamIntervention
Use this variant when the contract needs to represent unsafe stream intervention; selecting it has no side effect by itself.
ToolDenied
Use this variant when the contract needs to represent tool denied; selecting it has no side effect by itself.
ApprovalDenied
Use this variant when the contract needs to represent approval denied; selecting it has no side effect by itself.
ApprovalTimeout
Use this variant when the contract needs to represent approval timeout; selecting it has no side effect by itself.
ApprovalTransportFatal
Use this variant when the contract needs to represent approval transport fatal; selecting it has no side effect by itself.
ToolFailure
Use this variant when the contract needs to represent tool failure; selecting it has no side effect by itself.
ResumeDenied
Use this variant when the contract needs to represent resume denied; selecting it has no side effect by itself.
RecoveryCompleted
Use this variant when the contract needs to represent recovery completed; selecting it has no side effect by itself.
RecoveryIrrecoverable
Use this variant when the contract needs to represent recovery irrecoverable; selecting it has no side effect by itself.