pub enum IsolationCapability {
Show 19 variants
ReadOnlyRoot,
WritableLayer,
MountReadOnlyEnforcement,
SingleFileMountExpansionAudit,
NoNetworkGuarantee,
EgressAllowlist,
SecretIsolation,
SecretMount,
SecretRedaction,
ProcessTimeout,
ProcessSignal,
ProcessRlimits,
ContentRefIo,
IoRedaction,
ProcessStats,
Cleanup,
Detach,
Reclaim,
AuditLog,
}Expand description
Enumerates the finite isolation capability cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
ReadOnlyRoot
Use this variant when the contract needs to represent read only root; selecting it has no side effect by itself.
WritableLayer
Use this variant when the contract needs to represent writable layer; selecting it has no side effect by itself.
MountReadOnlyEnforcement
Use this variant when the contract needs to represent mount read only enforcement; selecting it has no side effect by itself.
SingleFileMountExpansionAudit
Use this variant when the contract needs to represent single file mount expansion audit; selecting it has no side effect by itself.
NoNetworkGuarantee
Use this variant when the contract needs to represent no network guarantee; selecting it has no side effect by itself.
EgressAllowlist
Use this variant when the contract needs to represent egress allowlist; selecting it has no side effect by itself.
SecretIsolation
Use this variant when the contract needs to represent secret isolation; selecting it has no side effect by itself.
SecretMount
Use this variant when the contract needs to represent secret mount; selecting it has no side effect by itself.
SecretRedaction
Use this variant when the contract needs to represent secret redaction; selecting it has no side effect by itself.
ProcessTimeout
Use this variant when the contract needs to represent process timeout; selecting it has no side effect by itself.
ProcessSignal
Use this variant when the contract needs to represent process signal; selecting it has no side effect by itself.
ProcessRlimits
Use this variant when the contract needs to represent process rlimits; selecting it has no side effect by itself.
ContentRefIo
Use this variant when the contract needs to represent content ref io; selecting it has no side effect by itself.
IoRedaction
Use this variant when the contract needs to represent io redaction; selecting it has no side effect by itself.
ProcessStats
Use this variant when the contract needs to represent process stats; selecting it has no side effect by itself.
Cleanup
Use this variant when the contract needs to represent cleanup; selecting it has no side effect by itself.
Detach
Use this variant when the contract needs to represent detach; selecting it has no side effect by itself.
Reclaim
Use this variant when the contract needs to represent reclaim; selecting it has no side effect by itself.
AuditLog
Use this variant when the contract needs to represent audit log; selecting it has no side effect by itself.