pub enum MissingDependency {
PolicySnapshot,
PolicyRef,
PermissionEvaluator,
SandboxEvaluator,
ApprovalDispatcher,
Adapter,
Sink,
Store,
JournalAppend,
ExecutorRef,
IsolationRuntime,
}Expand description
Enumerates the finite missing dependency cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
PolicySnapshot
Use this variant when the contract needs to represent policy snapshot; selecting it has no side effect by itself.
PolicyRef
Use this variant when the contract needs to represent policy ref; selecting it has no side effect by itself.
PermissionEvaluator
Use this variant when the contract needs to represent permission evaluator; selecting it has no side effect by itself.
SandboxEvaluator
Use this variant when the contract needs to represent sandbox evaluator; selecting it has no side effect by itself.
ApprovalDispatcher
Use this variant when the contract needs to represent approval dispatcher; selecting it has no side effect by itself.
Adapter
Use this variant when the contract needs to represent adapter; selecting it has no side effect by itself.
Sink
Use this variant when the contract needs to represent sink; selecting it has no side effect by itself.
Store
Use this variant when the contract needs to represent store; selecting it has no side effect by itself.
JournalAppend
Use this variant when the contract needs to represent journal append; selecting it has no side effect by itself.
ExecutorRef
Use this variant when the contract needs to represent executor ref; selecting it has no side effect by itself.
IsolationRuntime
Use this variant when the contract needs to represent isolation runtime; selecting it has no side effect by itself.
Implementations
Sourceimpl MissingDependency
impl MissingDependency
Sourcepub fn reason_code(self) -> &'static str
pub fn reason_code(self) -> &'static str
Returns the reason code currently held by this value. This is data-only and does not perform I/O, call host ports, append journals, publish events, or start processes.
Sourcepub fn to_error(self, causal_ids: CausalIds) -> AgentError
pub fn to_error(self, causal_ids: CausalIds) -> AgentError
Converts this value into error data. This is data-only and does not perform I/O, call host ports, append journals, publish events, or start processes.