pub enum RealtimeSessionStatus {
Show 13 variants
Connecting,
Connected,
InputSent,
OutputReceived,
Interrupted,
RestartRequested,
RestartStarted,
RestartCompleted,
RestartFailed,
Closed,
Failed,
Detached,
BackpressureApplied,
}Expand description
Enumerates the finite realtime session status cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Connecting
Use this variant when the contract needs to represent connecting; selecting it has no side effect by itself.
Connected
Use this variant when the contract needs to represent connected; selecting it has no side effect by itself.
InputSent
Use this variant when the contract needs to represent input sent; selecting it has no side effect by itself.
OutputReceived
Use this variant when the contract needs to represent output received; selecting it has no side effect by itself.
Interrupted
Use this variant when the contract needs to represent interrupted; selecting it has no side effect by itself.
RestartRequested
Use this variant when the contract needs to represent restart requested; selecting it has no side effect by itself.
RestartStarted
Use this variant when the contract needs to represent restart started; selecting it has no side effect by itself.
RestartCompleted
Use this variant when the contract needs to represent restart completed; selecting it has no side effect by itself.
RestartFailed
Use this variant when the contract needs to represent restart failed; selecting it has no side effect by itself.
Closed
Use this variant when the contract needs to represent closed; selecting it has no side effect by itself.
Failed
Use this variant when the contract needs to represent failed; selecting it has no side effect by itself.
Detached
Use this variant when the contract needs to represent detached; selecting it has no side effect by itself.
BackpressureApplied
Use this variant when the contract needs to represent backpressure applied; selecting it has no side effect by itself.