pub enum CursorCompatibility {
Compatible,
ScopeMismatch,
}Expand description
Enumerates the finite cursor compatibility cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Compatible
Use this variant when the contract needs to represent compatible; selecting it has no side effect by itself.
ScopeMismatch
Use this variant when the contract needs to represent scope mismatch; selecting it has no side effect by itself.