pub struct FakeContentResolver { /* private fields */ }Expand description
In-memory fake content resolver fixture for SDK conformance tests. Use it to script deterministic behavior in memory; any transcript or endpoint mutation is documented on the method that performs it.
Implementations
Sourceimpl FakeContentResolver
impl FakeContentResolver
Sourcepub fn insert_text(&self, content_ref: &ContentRef, text: impl Into<String>)
pub fn insert_text(&self, content_ref: &ContentRef, text: impl Into<String>)
Insert text. This reads or mutates deterministic in-memory test state unless the method explicitly names a fixture file.
Sourcepub fn assert_conformance<R: ContentResolver>(
resolver: &R,
present_ref: ContentRef,
missing_ref: ContentRef,
policy: ContentResolutionPolicy,
)
pub fn assert_conformance<R: ContentResolver>( resolver: &R, present_ref: ContentRef, missing_ref: ContentRef, policy: ContentResolutionPolicy, )
Assert conformance. This reads or mutates deterministic in-memory test state unless the method explicitly names a fixture file.